##
##  gnupg.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2005 OpenPKG Foundation e.V. <http://openpkg.net/>
##  Copyright (c) 2000-2005 Ralf S. Engelschall <http://engelschall.com/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         gnupg
Summary:      GNU Privacy Guard
URL:          http://www.gnupg.org/
Vendor:       Werner Koch
Packager:     OpenPKG
Distribution: OpenPKG
Class:        BASE
Group:        Cryptography
License:      GPL
Version:      1.4.2
Release:      20050727

#   package options
%option       with_idea  no
%option       with_ldap  no

#   list of sources
Source0:      ftp://ftp.gnupg.org/gcrypt/gnupg/gnupg-%{version}.tar.gz
Source1:      ftp://ftp.gnupg.dk/pub/contrib-dk/idea.c.gz

#   build information
Prefix:       %{l_prefix}
BuildRoot:    %{l_buildroot}
BuildPreReq:  OpenPKG, openpkg >= 20040130, make
PreReq:       OpenPKG, openpkg >= 20040130
BuildPreReq:  zlib, bzip2, readline
PreReq:       zlib, bzip2, readline
%if "%{with_ldap}" == "yes"
BuildPreReq:  openldap, openssl
PreReq:       openldap, openssl
%endif
AutoReq:      no
AutoReqProv:  no

%description
     GnuPG (GNU Privacy Guard) is a GNU utility for encrypting data and
     creating digital signatures. GnuPG has advanced key management
     capabilities and is compliant with the proposed OpenPGP Internet
     standard described in RFC2440. Since GnuPG doesn't use any patented
     algorithm, it is not compatible with any version of PGP2 (PGP2.x
     uses only IDEA, patented worldwide).

%track
    prog gnupg = {
        version   = %{version}
        url       = ftp://ftp.gnupg.org/gcrypt/gnupg/
        regex     = gnupg-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
%if "%{with_idea}" == "yes"
    %{l_gzip} -d -c %{SOURCE idea.c.gz} >cipher/idea.c
%endif

%build
    LIBS=""
    echo "int main(int argc, char *argv[]) { return 0; }" >dummy.c
    for lib in termcap termlib curses ncurses; do
        rc=0; %{l_cc} -o dummy dummy.c -l$lib >/dev/null 2>&1 || rc=1
        if [ $rc -eq 0 ]; then LIBS="$LIBS -l$lib"; break; fi
    done
%if "%{with_ldap}" == "yes"
    LIBS="$LIBS -lssl -lcrypto"
%endif
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    LIBS="$LIBS" \
    ./configure \
        --prefix=%{l_prefix} \
        --with-zlib=%{l_prefix} \
        --with-bzip2=%{l_prefix} \
        --enable-exec \
        --enable-keyserver-helpers \
%if "%{with_ldap}" == "yes"
        --enable-ldap \
%else
        --disable-ldap \
%endif
        --enable-finger \
        --enable-http \
        --enable-hkp \
        --disable-mailto \
        --disable-gnupg-iconv \
        --without-included-gettext \
        --disable-nls
    %{l_make} %{l_mflags}

%install
    rm -rf $RPM_BUILD_ROOT
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* 2>/dev/null || true
    rm -f $RPM_BUILD_ROOT%{l_prefix}/info/dir
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%attr(4755,%{l_susr},%{l_mgrp}) %{l_prefix}/bin/gpg'

%files -f files

%clean
    rm -rf $RPM_BUILD_ROOT

